@@ -11,9 +11,12 @@ Submodules
    gftool.beb
    gftool.cpa
    gftool.fourier
+   gftool.hermpade
    gftool.lattice
+   gftool.linearprediction
    gftool.matrix
    gftool.pade
+   gftool.polepade
    gftool.siam
 
 Glossary
@@ -55,7 +58,7 @@ import numpy as np
 
 from numpy import newaxis
 
-from . import beb, cpa, fourier, lattice, matrix as gtmatrix
+from . import beb, cpa, fourier, lattice, matrix as gtmatrix, linearprediction, polepade
 from ._util import _gu_sum
 from ._version import get_versions
 
@@ -85,10 +88,10 @@ from .lattice.triangular import (dos as triangular_dos,
                                  hilbert_transform as triangular_hilbert_transform)
 
 # Honeycomb lattice
-from .lattice.honeycomb import(dos as honeycomb_dos,
-                               dos_moment as honeycomb_dos_moment,
-                               gf_z as honeycomb_gf_z,
-                               hilbert_transform as honeycomb_hilbert_transform)
+from .lattice.honeycomb import (dos as honeycomb_dos,
+                                dos_moment as honeycomb_dos_moment,
+                                gf_z as honeycomb_gf_z,
+                                hilbert_transform as honeycomb_hilbert_transform)
 
 # Simple cubic lattice
 from .lattice.sc import (dos as sc_dos,
@@ -129,7 +132,7 @@ __version__ = get_versions()['version']
 LOGGER = logging.getLogger(__name__)
 
 # silence warnings of unused imports
-assert all((beb, cpa, fourier, lattice))
+assert all((beb, cpa, fourier, lattice, linearprediction, polepade))
 assert all((bethe_dos, bethe_dos_moment, bethe_gf_d1_z, bethe_gf_d2_z,
             bethe_gf_z, bethe_hilbert_transform))
 assert all((onedim_dos, onedim_dos_moment, onedim_gf_z, onedim_hilbert_transform))
@@ -166,7 +169,7 @@ def surface_gf_zeps(z, eps, hopping_nn):
     Returns
     -------
     surface_gf_zeps : complex
-        Value of the surface Green's function
+        Value of the surface Green's function.
 
     References
     ----------
@@ -296,15 +299,15 @@ def pole_gf_tau_b(tau, poles, weights, beta):
     pole_gf_tau_b : (...) float np.ndarray
         Imaginary time Green's function.
 
-    See Also
-    --------
-    pole_gf_z : corresponding commutator Green's function
-
     Raises
     ------
     ValueError
         If any `poles.real <= 0`.
 
+    See Also
+    --------
+    pole_gf_z : Corresponding commutator Green's function.
+
     Examples
     --------
     >>> beta = 10
