@@ -29,11 +29,6 @@ from gftool._util import _gu_sum
 polyvander = np.polynomial.polynomial.polyvander
 
 
-def _get_otype(*args):
-    """Determine the resulting type if arrays are broadcasted."""
-    return sum(np.asarray(arg).reshape(-1)[:1] for arg in args).dtype
-
-
 def _chebyshev_points(num: int) -> np.ndarray:
     """Return `num` Chebyshev points."""
     return np.sin(0.5 * np.pi / num * np.arange(-num+1, num+1, 2))
@@ -300,9 +295,9 @@ def gf_z(z, poles, weights):
 
     See Also
     --------
-    gf_d1_z : First derivative of the Green's function
-    gf_tau : corresponding fermionic imaginary time Green's function
-    gt.pole_gf_tau_b : corresponding bosonic imaginary time Green's function
+    gf_d1_z : First derivative of the Green's function.
+    gf_tau : Corresponding fermionic imaginary time Green's function.
+    gt.pole_gf_tau_b : Corresponding bosonic imaginary time Green's function.
 
     """
     poles = np.atleast_1d(poles)
@@ -368,7 +363,7 @@ def gf_tau(tau, poles, weights, beta):
 
     See Also
     --------
-    pole_gf_z : corresponding commutator Green's function
+    pole_gf_z : Corresponding commutator Green's function.
 
     """
     assert np.all((tau >= 0.) & (tau <= beta))
@@ -400,7 +395,7 @@ def gf_ret_t(tt, poles, weights):
 
     See Also
     --------
-    pole_gf_z : corresponding commutator Green's function
+    pole_gf_z : Corresponding commutator Green's function.
 
     """
     poles = np.atleast_1d(poles)
@@ -565,7 +560,7 @@ def gf_from_z(z, gf_z, n_pole, moments=(), width=1., weight=None) -> PoleFct:
     gf_sp_mat = _gf_z(z[..., newaxis], poles[..., newaxis, :, newaxis], weights=1)
     gf_sp_mat = np.concatenate([gf_sp_mat.real, gf_sp_mat.imag], axis=-2)
     gf_z = np.concatenate([gf_z.real, gf_z.imag], axis=-1)
-    otype = _get_otype(gf_z, moments, poles)
+    otype = np.result_type(gf_z, moments, poles)
     if weight is not None:
         weight = np.concatenate([weight, weight], axis=-1)
         gf_sp_mat *= weight[..., np.newaxis]
@@ -636,7 +631,7 @@ def gf_from_tau(gf_tau, n_pole, beta, moments=(), occ=False, width=1., weight=No
     tau = np.linspace(0, beta, num=gf_tau.shape[-1])
     gf_sp_mat = _single_pole_gf_tau(tau[..., newaxis], poles, beta=beta)
     moments = np.asarray(moments)
-    otype = _get_otype(gf_tau, moments, poles)
+    otype = np.result_type(gf_tau, moments, poles)
     if weight is not None:
         gf_sp_mat *= weight[..., np.newaxis]
         gf_tau = gf_tau * weight
