@@ -10,8 +10,10 @@ path.insert(0, os.path.join(PATH, os.pardir, os.pardir))
 import gftool
 import gftool.beb
 import gftool.cpa
+import gftool.hermpade
 import gftool.matrix
 import gftool.fourier
+import gftool.polepade
 import gftool.pade as gt_pade
 import gftool.linalg
 import gftool.basis.pole as pole
